red = Color.new(255,0,0)
green = Color.new(0,255,0)
blue = Color.new(0,0,255)
tiles = Image.load("data/stagefive.png")
figure = Image.load("data/player.png")
counter = Timer.new()
counter:reset(0)

mapSource = {
  "mmmmmmmmmmmmmmmmmmmmmmmmmmmmmm",
  "mnnnnnbnnonnnbobonbnonnnnnnnnm",
  "mnnpnnbncccncbnbnnbnnnnnnnnnnm",
  "mnnnnnbnnonnnbnbnnbnnbcccccnnm",
  "mnnnnnbncccncbnbnnbnnbnnnnnnnm",
  "mnnnnnbnnnnnnbnbnnbnnbnnnnnnom",
  "mnnnnnbnnnnnnnnnnnnnnbnncccccm",
  "mnnnnnnnnnnnnbnbnnbnnbnnnnnnnm",
  "mcccccccccccccccccccccccccccnm",
  "monnnnbnonbonnnnnbnnnbnnbobnnm",
  "mcccnnbnnnbnnnnnnbnnnnnnbnbnnm",
  "mnnnnnnnnnbnnbnnnbnnnnnnbnbnnm",
  "mnnnnnnnnnbnnbncccnncbnnbnbnnm",
  "mnncccbnnnbnnbnnnnnnnbnnbnbnnm",
  "mnnnnnbnnnnnnbnnnnnnnbnnnnnnnm",
  "mnnnnobnnnnnnbnnnbnnnbnnnnnnnm",
  "mmmmmmmmmmmmmmmmmmmmmmmmmmmmmm"
}
 
-- offsreen image, where the map will be drawn
board = Image.createEmpty(480, 272)
 
-- draw one tile on the map
function drawTile(tile, x, y)
	tile = string.byte(tile, 1) - string.byte("a")
	local tileX = math.mod(tile, 4)
	local tileY = math.floor(tile / 4)
	board:blit(16 * x, 16 * y, tiles, 17 * tileX + 1, 17 * tileY + 1, 16, 16, false)
end	
 
-- copy the map source to an array for easier access and draw the offscreen board
map = {}
for y = 1, 17 do
	line = mapSource[y]
	map[y] = {}
	for x = 1, 30 do
		tile = string.sub(line, x, x)
		map[y][x] = tile
		drawTile(tile, x - 1, y - 1)
	end
end
 
-- current player position
playerX = 6
playerY = 14
 
-- current player animation image
animation = 0
 
-- 1 = animation images increases, -1: decreases
animationDirection = 1
 
-- animation slowdown counter
animationSlowDown = 0
 
-- controls the movement speed. At speedStep == 0, the last
-- pad will be evaluated, other steps the pad movements are only
-- saved
speedStep = 0
 
-- last pad direction
dx = 0
dy = 0
 
-- current score
score = 0
 
-- text color
white = Color.new(255, 255, 255)
 
while true do

 counter:start()
 currentTime = counter:time()
 if currentTime >= 120000  then
    screen:clear()
    screen:print(10,130,"Game Over Press Start",red)
    screen.flip()
    screen.waitVblankStart(60)
     
    screen:clear()
    screen.flip()
   
  end
	-- read current pad
	pad = Controls.read()
	
	if pad:start() then
		-- exit to lowser, if started from there
		break
	end
	if speedStep == 0 then
		-- save old player position
		oldPlayerX = playerX
		oldPlayerY = playerY
		
		-- add last movement
		playerX = playerX + dx
		playerY = playerY + dy
		
		-- check new tile
		newTile = map[playerY][playerX]
		
		-- if the position is not allowed, restore old player position
		if newTile ~= "n" and newTile ~= "p" and newTile ~= "o" then
			playerX = oldPlayerX
			playerY = oldPlayerY
		end
		
		-- if it is a tile which can be eaten, eat it
		if newTile == "p" then score = score + 5 end
		if newTile == "o" then score = score + 1 end
		if newTile == "p" or newTile == "o" then
			-- set background tile
			map[playerY][playerX] = "n"
 
			-- draw background tile
			drawTile("n", playerX - 1, playerY - 1)
		end
		
		-- reset last movement
		dx = 0
		dy = 0
	else
		-- check pad movement
		if pad:up() then
			dy = -1
		elseif pad:down() then
			dy = 1
		elseif pad:left() then
			dx = -1
		elseif pad:right() then
			dx = 1
		end
	end
	
	-- update speed step counter
	speedStep = speedStep + 1
	if speedStep == 5 then
		speedStep = -1
	end
	
	-- blit board
	screen:blit(0, 0, board, 0, 0, board:width(), board:height(), false)
	
	-- blit current player animation image
	screen:blit((playerX - 1) * 16 - 4, (playerY - 1) * 16 - 4, figure, 1 + 25 * animation, 1, 24, 24)
	
	-- calculate next animation image
	animationSlowDown = animationSlowDown + 1
	if animationSlowDown == 3 then
		animationSlowDown = 0
		animation = animation + animationDirection
		if animation == 4 then
			animationDirection = -1
		elseif animation == 0 then
			animationDirection = 1
		end
	end
	
	-- print score
	screen:print(10, 260, "Score: " .. score, white)
	
  screen:print(10,10,"Counter Time: " .. currentTime,white)
	-- wait for vertical sync and show new screen
	screen.waitVblankStart()
	screen:flip()
end
if score == 16 then
  screen:clear()
  screen:print(10,130,"Press Start To Finish",red)
  screen.flip()
end

